/*
** Copyright (C) 16 Mar 1999 Jonas Munsin <jmunsin@iki.fi>
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** 
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software 
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

enum {
	RESET_BUTTON = 1
};
typedef struct {
	GtkWidget *widget;
	GtkWidget *hbox; /* this is kind of ugly */
	GtkWidget *swab_audio;
	GtkWidget *scsibus;
	GtkWidget *target;
	GtkWidget *lun;
	GtkWidget *driver;
	GtkWidget *device;
	GtkWidget *fifo;
} config_cdr_data;
extern config_cdr_data *config_cdr(int);

typedef struct {
	char *title;
	gpointer *func;
} file_req_info;

void set_notebook_tab(GtkWidget *, gint, GtkWidget *);
void choose_path(GtkWidget *, gpointer);
void alert_user_of_error(gchar *);
void alert_user_of_error_msg(gchar *, gchar *);
GtkWidget *make_frame(gchar *, gint);
void close_dialog(GtkWidget *, gpointer);

void cursor_wait(GtkWidget *);
void cursor_reset(GtkWidget *);
